body_escapes_params

Function body_escapes_params 

fn body_escapes_params<'hir>(
    hir: &'hir Hir<'hir>,
    body: &Block<'hir>,
    params: &[VariableId],
) -> bool
Returns true if any param is written, aliased, or passed to a callee that could mutate it via the internal-call memory-reference aliasing rule.