lhs_is_local_memory_reference

Function lhs_is_local_memory_reference 

fn lhs_is_local_memory_reference(hir: &Hir<'_>, lhs: &Expr<'_>) -> bool
Returns true if the root of lhs resolves to a local variable with reference type in memory.