fn modifier_args_reference_params(
modifiers: &[Modifier<'_>],
params: &[VariableId],
) -> boolExpand description
Returns true if any modifier invocation passes one of params as an argument.
Modifier memory args alias caller memory the same way internal call args do.